# CPU type
set cpu_type TMS320C2800

# Flash support
set flash_types { 0 1 2 3 }

# target-side code of flash loader
set FlashLoadSuppCode $mypath/trgcode/flash2806.out

# target is little endian
set TargetBigEndian 0

# PC register name
set pc_name PC
##############################################################
# base address of I2C controller
set i2c0_base 0x7900
##############################################################
# base address of SPI0 controller
set spi0_base 0x7040

# base address of SPI1 controller
set spi1_base 0x7740

# base address of SPI2 controller
set spi2_base 0x7760

# base address of SPI3 controller
set spi3_base 0x7780

# Word width (0 - 8 bit, 1 - 16, 2 - 32)
set word_width 1

##############################################################
# start address of flash itself in CPU's address space
#
set internal_flash_base 0x3F0000

# parameters of Internal Flash
# TMS320C2806 & 2802 contains 4 sectors, 16 Kbyte size

set internal_flash_sectors  {
  { 16384 3 }
  { 16384 2 }
  { 16384 1 }
  { 16384 0 } }

# Max core frequency in Hz
set cpu_fmax 100000000

##############################################################
#Calculate max posible frequency of CPU
##############################################################
set i 10
set brd_fmax [expr $quarz_frequency*$i/2]

while {$brd_fmax>$cpu_fmax} {
    set brd_fmax [expr $quarz_frequency*$i/2]	
    set i [expr $i - 1]
}

# Set time of command cycle in nS
set cycle_time [expr 1000000000 / $brd_fmax]

# Set flash scale factor
set flash_scale [expr 1048576*200/$cycle_time]


###########################################################################
# CPU clock frequency
###########################################################################
set cpu_clock $brd_fmax
set periph_clock $brd_fmax


###########################################################################
# CPU-specific initialization
###########################################################################
proc CPUSpecificInit { dev } {
                  
  upvar 1 flash_type flash_type
  upvar 1 csm_password csm_password 
  upvar 1 iftype iftype
  upvar 1 brd_fmax brd_fmax  
  upvar 1 quarz_frequency quarz_frequency

  # OBJMODE=1
  # AMODE=0
  WriteReg $dev ST1 [expr ([ReadReg $dev ST1] & 0xFEFF) | 0x200]

  puts "Unlocking CSM"

  # Unlock CSM
  #
  ReadShort $dev 0x3F7FF8 1
  ReadShort $dev 0x3F7FF9 1
  ReadShort $dev 0x3F7FFA 1
  ReadShort $dev 0x3F7FFB 1
  ReadShort $dev 0x3F7FFC 1
  ReadShort $dev 0x3F7FFD 1
  ReadShort $dev 0x3F7FFE 1
  ReadShort $dev 0x3F7FFF 1

  PutShort $dev 0xAE0 1 [lindex $csm_password 0]
  PutShort $dev 0xAE1 1 [lindex $csm_password 1]
  PutShort $dev 0xAE2 1 [lindex $csm_password 2]
  PutShort $dev 0xAE3 1 [lindex $csm_password 3]
  PutShort $dev 0xAE4 1 [lindex $csm_password 4]
  PutShort $dev 0xAE5 1 [lindex $csm_password 5]
  PutShort $dev 0xAE6 1 [lindex $csm_password 6]
  PutShort $dev 0xAE7 1 [lindex $csm_password 7]

  puts "Stop the WD Timer"
  PutShort $dev 0x7029 1 0x00E8
  puts [format "0xWDCR=0x%04x" [ReadShort $dev 0x7029 1]]

  # Set PLL parameters

  set PLLSTS [ReadShort $dev 0x7011 1]
  set PLLCR [expr 2*$brd_fmax/$quarz_frequency]
  if { ($PLLSTS & 0x08) != 8} {
     PutShort $dev 0x7011 1 [expr $PLLSTS | 0x40]
     PutShort $dev 0x7021 1 $PLLCR
     PutShort $dev 0x7029 1 0x0068
     PutShort $dev 0x7011 1 [expr [ReadShort $dev 0x7011 1] & 0xFFBF]
  } else {
    xerror $dev "CPU's PLL is in limp mode (no input clock), can't continue" 1
  }

  puts "Peripheral clock= SYSCLKOUT/1 "
  PutShort $dev 0x701A 1 0x0
  puts [format "HISPCP=0x%04x" [ReadShort $dev 0x701A 1]] 
  PutShort $dev 0x701B 1 0x0
  puts [format "LOSPCP=0x%04x" [ReadShort $dev 0x701B 1]] 


  if { $flash_type == 0 } {

    # Enable I2C pins

    puts "Configuring mux to enable I2C pins"
    # GPAPUD
    PutShort $dev 0x6F9C 1 0x0000
    # GPBQSEL1
    PutShort $dev 0x6F92 1 0x000F
    # GPBMUX1
    PutShort $dev 0x6F96 1 0x0005

    # Enable I2C clock

    puts "Enabling I2C module clock"
    # PCLKCR0
    PutShort $dev 0x701C 1 0x0010

  }
  if { $flash_type == 2  && $iftype == 3 } {

        # Enable SPI pins
        # GPAPUD for All pins
        PutShort $dev 0x6F8C 1 0x0000
        PutShort $dev 0x6F8D 1 0x0000
      
        # GPAQSEL1
        PutShort $dev 0x6F82 1 0x0CCC        
	# GPAQSEL1
        PutShort $dev 0x6F83 1 0x3F00
	# GPAQSEL2
	PutShort $dev 0x6F84 1 0x3F3F
        # GPAMUX1
        PutShort $dev 0x6F86 1 0x0888
        # GPAMUX1
        PutShort $dev 0x6F87 1 0x3F00
        # GPAMUX2
	PutShort $dev 0x6F88 1 0x2A15

        puts [format "GPAQSEL1.Low=0x%04x" [ReadShort $dev 0x6F82 1]] 
        puts [format "GPAQSEL1.High=0x%04x" [ReadShort $dev 0x6F83 1]] 
        puts [format "GPAQSEL2=0x%04x" [ReadShort $dev 0x6F84 1]] 
        puts [format "GPAMUX1.Low=0x%04x" [ReadShort $dev 0x6F86 1]] 
        puts [format "GPAMUX1.High=0x%04x" [ReadShort $dev 0x6F87 1]] 
        puts [format "GPAMUX2=0x%04x" [ReadShort $dev 0x6F88 1]] 
   	puts --------------------------------------------------  
    	PutShort $dev 0x701C 1 0x03C0
   }

}




